cachetools: Extensible memoizing collections and decorators
===========================================================

Description
-----------

Extensible memoizing collections and decorators

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/cachetools/

